#
# spec file for package python2-jupyter_ipython
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without iptest

%define         oldpython python
Name:           python2-jupyter_ipython
Version:        5.8.0
Release:        4.1
Summary:        Rich architecture for interactive computing with Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/ipython/ipython
Source:         https://files.pythonhosted.org/packages/source/i/ipython/ipython-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/jupyter/qtconsole/4.0.0/qtconsole/resources/icon/JupyterConsole.svg
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  update-desktop-files
%if %{with iptest}
BuildRequires:  python-backports.shutil_get_terminal_size
BuildRequires:  python-decorator
BuildRequires:  python-jupyter_nbformat
BuildRequires:  python-matplotlib
BuildRequires:  python-mock
BuildRequires:  python-nose
BuildRequires:  python-pathlib2
BuildRequires:  python-pexpect
BuildRequires:  python-pickleshare
BuildRequires:  python-prompt_toolkit1 >= 1.0.4
BuildRequires:  python-requests
BuildRequires:  python-simplegeneric > 0.8
BuildRequires:  python-testpath
BuildRequires:  python-traitlets
%endif
%if %{with ico}
BuildRequires:  icoutils
%endif
Requires:       python-Pygments
Requires:       python-backports.shutil_get_terminal_size
Requires:       python-decorator
Requires:       python-jedi >= 0.10
Requires:       python-pathlib2
Requires:       python-pexpect
Requires:       python-pickleshare
Requires:       python-prompt_toolkit1 >= 1.0.4
Requires:       python-simplegeneric > 0.8
Requires:       python-traitlets >= 4.2
Requires:       python-typing
Recommends:     python-docrepr
Recommends:     python-jupyter_ipykernel
Recommends:     python-jupyter_ipyparallel
Recommends:     python-jupyter_ipywidgets
Recommends:     python-jupyter_nbconvert
Recommends:     python-jupyter_nbformat
Recommends:     python-jupyter_notebook
Recommends:     python-jupyter_qtconsole
Provides:       IPython = %{version}
Obsoletes:      IPython < %{version}
Provides:       python-IPython = %{version}
Obsoletes:      python-IPython < %{version}
Provides:       %{oldpython}-IPython = %{version}
Provides:       %{oldpython}-IPython = %{version}
Provides:       %{oldpython}-jupyter_ipython = %{version}
Obsoletes:      %{oldpython}-jupyter_ipython < %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%description
IPython provides a rich toolkit to help you make the
most out of using Python interactively. Its main
components are:

 * A powerful interactive Python shell
 * A Jupyter kernel to work with Python code in
   Jupyter notebooks and other interactive frontends.

The enhanced interactive Python shells have the
following main features:

 * Comprehensive object introspection.
 * Input history, persistent across sessions.
 * Caching of output results during a session with automatically
   generated references.
 * Extensible tab completion, with support by default for completion
   of python variables and keywords, filenames and function keywords.
 * Extensible system of ‘magic’ commands for controlling the
   environment and performing many tasks related either to IPython or
   the operating system.
 * A rich configuration system with easy switching between different
   setups (simpler than changing $PYTHONSTARTUP environment variables
   every time).
 * Session logging and reloading.
 * Extensible syntax processing for special purpose situations.
 * Access to the system shell with user-extensible alias system.
 * Easily embeddable in other Python programs and GUIs.
 * Integrated access to the pdb debugger and the Python profiler.
 
IMPORTANT: The Python 2 version of IPython is in long-term support
mode. It will not be receiving major new features. Starting with
IPython 6, only Python 3.3 and later is supported.
 
%package iptest
Summary:        Tools for testing packages that rely in %{name}
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-matplotlib
Requires:       python-nose
Requires:       python-requests
Requires:       python-testpath
# Python 2 Test Requirements
Requires:       python-mock
Provides:       python-jupyter_ipython-iptest = %{version}
Obsoletes:      python-jupyter_ipython-iptest < %{version}

%description iptest
This package provides the iptest command, which is used for
testing software that uses %{name}.
 
IMPORTANT: The Python 2 version of IPython is in long-term support
mode. It will not be receiving major new features. Starting with
IPython 6, only Python 3.3 and later is supported.

%prep
%setup -q -n ipython-%{version}

sed -i "s|#!/usr/bin/env python|#!/usr/bin/python|" IPython/testing/plugin/iptest.py
sed -i "s|#!/usr/bin/env python|#!/usr/bin/python|" IPython/testing/plugin/setup.py
sed -i "s|#!/usr/bin/env python|#!/usr/bin/python|" IPython/terminal/ipapp.py

find . -type f -name "*.py" -exec sed -i "s|#!/usr/bin/python|#!/usr/bin/python2|" {} \;

%build
python setup.py build

%if %{with ico}
pushd scripts
icotool -x ipython.ico
icotool -x ipython_nb.ico
popd
%endif

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for p in ipython iptest ; do
    sed -i "s|#!/usr/bin/python|#!/usr/bin/python2|" %{buildroot}%{_bindir}/${p}
    sed -i "s|#!/usr/bin/python|#!/usr/bin/python2|" %{buildroot}%{_bindir}/${p}2
    mv %{buildroot}%{_bindir}/$p %{buildroot}%{_bindir}/$p-%{py_ver}
    ln -s -f %{_sysconfdir}/alternatives/$p %{buildroot}%{_bindir}/$p
    # create a dummy target for /etc/alternatives/$p
    touch %{buildroot}%{_sysconfdir}/alternatives/$p
done

mv %{buildroot}%{_mandir}/man1/ipython.1 %{buildroot}%{_mandir}/man1/ipython-%{py_ver}.1
ln -s -f %{_sysconfdir}/alternatives/ipython.1.gz %{buildroot}%{_mandir}/man1/ipython.1.gz
# create a dummy target for /etc/alternatives/ipython.1.gz
touch %{buildroot}%{_sysconfdir}/alternatives/ipython.1.gz

# We also want a manual for ipython2
ln -s %{_mandir}/man1/ipython-%{py_ver}.1.gz %{buildroot}%{_mandir}/man1/ipython2.1.gz

# These can be run stand-alone, so make them executable rather than removing shebang
chmod a+x %{buildroot}%{python_sitelib}/IPython/external/mathjax.py
chmod a+x %{buildroot}%{python_sitelib}/IPython/testing/plugin/iptest.py
chmod a+x %{buildroot}%{python_sitelib}/IPython/testing/plugin/setup.py
chmod a+x %{buildroot}%{python_sitelib}/IPython/terminal/ipapp.py

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
cp %{SOURCE1} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/IPython-%{py_ver}.svg
%if %{with ico}
# Install the icons
for x in 16 24 32 48 256 ; do
    mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}/apps/
    ipyf=(scripts/ipython_*_${x}x${x}x32.png)
    ipynbf=(scripts/ipython_nb_*_${x}x${x}x32.png)
    cp ${ipyf[0]} %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}/apps/IPython-%{py_ver}.png
    cp ${ipynbf[0]} %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}/apps/IPythonNotebook-%{py_ver}.png
done
%endif

# Modify and install .desktop file
mv examples/IPython\ Kernel/ipython.desktop ipython-%{py_ver}.desktop
desktop-file-edit --set-comment="Enhanced interactive Python %{py_ver} shell" --set-name="ipython %{py_ver}" --set-generic-name="IPython %{py_ver}" --set-key="Exec" --set-value="ipython-%{py_ver}" --set-icon="IPython-%{py_ver}" ipython-%{py_ver}.desktop
%suse_update_desktop_file -i -r ipython-%{python_version} "System;TerminalEmulator;"

rm %{buildroot}%{_bindir}/ipython2
ln -s %{_bindir}/ipython-%{py_ver} %{buildroot}%{_bindir}/ipython2

# Remove these since they won't work
%if !%{with iptest}
rm %{buildroot}%{_bindir}/iptest
rm %{buildroot}%{_bindir}/iptest2
rm %{buildroot}%{_bindir}/iptest-%{py_ver}
rm %{buildroot}%{_sysconfdir}/alternatives/iptest
%else
rm %{buildroot}%{_bindir}/iptest2
ln -s %{_bindir}/iptest-%{py_ver} %{buildroot}%{_bindir}/iptest2
%endif

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/ipython ipython %{_bindir}/ipython-%{py_ver} 30 \
   --slave %{_mandir}/man1/ipython.1.gz ipython.1.gz %{_mandir}/man1/ipython-%{py_ver}.1.gz
%desktop_database_post
%icon_theme_cache_post

%post iptest
%_sbindir/update-alternatives \
   --install %{_bindir}/iptest iptest %{_bindir}/iptest-%{py_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove ipython %{_bindir}/ipython-%{py_ver}
fi
%desktop_database_postun
%icon_theme_cache_postun

%postun iptest
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove iptest %{_bindir}/iptest-%{py_ver}
fi

%files
%doc README.rst 
%license COPYING.rst docs/source/about/license_and_copyright.rst
%{_bindir}/ipython
%{_bindir}/ipython2
%{_bindir}/ipython-%{py_ver}
%ghost %{_sysconfdir}/alternatives/ipython
%{_mandir}/man1/ipython.1.gz
%{_mandir}/man1/ipython-%{py_ver}.1.gz
%{_mandir}/man1/ipython2.1.gz
%ghost %{_sysconfdir}/alternatives/ipython.1.gz
%{python_sitelib}/IPython/
%{python_sitelib}/ipython-%{version}-py*.egg-info
%{_datadir}/applications/ipython-%{py_ver}.desktop
%{_datadir}/icons/hicolor/scalable/apps/IPython-%{py_ver}.svg
%if %{with ico}
%{_datadir}/icons/hicolor/*x*/apps/IPython-%{py_ver}.png
%{_datadir}/icons/hicolor/*x*/apps/IPythonNotebook-%{py_ver}.png
%endif

%if %{with iptest}
%files iptest
%doc README.rst 
%license COPYING.rst docs/source/about/license_and_copyright.rst
%{_bindir}/iptest
%{_bindir}/iptest2
%{_bindir}/iptest-%{py_ver}
%ghost %{_sysconfdir}/alternatives/iptest
%endif

%changelog
* Tue Feb  5 2019 alarrosa@suse.com
- Fix %%suse_update_desktop_file call to evaluate py_ver correctly
* Mon Oct  8 2018 toddrme2178@gmail.com
- Fix prompt_toolkit dependency
- Provide python-jupyter_ipython for backwards-compatibility
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 5.8.0
  * Update inspecting function/methods for future-proofing.
* Sun Jul 22 2018 toddrme2178@gmail.com
- Not compatible with prompt_toolkit 2.x
* Fri May 18 2018 toddrme2178@gmail.com
- Update to 5.7.0
  * Fix IPython trying to import non-existing matplotlib backends :ghpull:`11087`
  * fix for display hook not publishing object metadata :ghpull:`11101`
- Update to 5.6.0
  * In Python 3.6 and above, dictionaries preserve the order items were added to
    them. On these versions, IPython will display dictionaries in their native
    order, rather than sorting by the keys (:ghpull:`10958`).
  * :class:`~.IPython.display.ProgressBar` can now be used as an iterator
    (:ghpull:`10813`).
  * The shell object gains a :meth:`~.InteractiveShell.check_complete` method,
    to allow a smoother transition to new input processing machinery planned for
    IPython 7 (:ghpull:`11044`).
  * IPython should start faster, as it no longer looks for all available pygments
    styles on startup (:ghpull:`10859`).
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Mon Oct  9 2017 hpj@urpla.net
- fix conditional to allow build for older distributions
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to version 5.5.0
  * System Wide config
  * ProgressBar
  * Fix ``IPython.core.display:Pretty._repr_pretty_`` had the wrong signature.
  * :magic:`timeit` now give a correct ``SyntaxError`` if naked ``return`` used.
  * Prepare the ``:ipython:`` directive to be compatible with Sphinx 1.7.
  * Make IPython work with OpenSSL in FIPS mode; change hash algorithm of input
    from md5 to sha1.
  * Clear breakpoints before running any script with debugger.
  * Document that :magic:`profile` is deprecated, not to be confused with :magic:`prun`.
  * Limit default number of returned completions to 500.
* Wed Sep  6 2017 toddrme2178@gmail.com
- Rename to python2-jupyter_ipython to allow for single-spec
  package to be used for python3 version.
- Delete -doc subpackage. Docs are being built in the singlespec
  version only now.
* Fri Aug 11 2017 toddrme2178@gmail.com
- Update to version 5.4.1
  * Released a few hours after 5.4, fix a crash when
    ``backports.shutil-get-terminal-size`` is not installed. :ghissue:`10629`
- Update to version 5.4
  * Configurable TerminalInteractiveShell
  * Define ``_repr_mimebundle_``
  * Execution Heuristics
  * Implement Display IDs
  * Display function
  * ``_mp_main_`` is not reloaded which fixes issues with multiprocessing.
    :ghpull:`10523`
  * Use user colorscheme in Pdb as well :ghpull:`10479`
  * Faster shutdown. :ghpull:`10408`
  * Fix a crash in reverse search. :ghpull:`10371`
  * added ``Completer.backslash_combining_completions`` boolean option to
    deactivate backslash-tab completion that may conflict with windows path.
- Fix building on platforms without icoutils
* Thu Jul 13 2017 toddrme2178@gmail.com
- Fix shebang rpmint errors.
* Mon Apr 24 2017 toddrme2178@gmail.com
- Add note about LTS status and the end of Python 2 support.
- Add python2- provides.
- Neither HTML nor PDF documentation will ever work again,
  so drop it.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Install icons.
- Install .desktop file.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to IPython 5.3
  * Fix a bug in ``set_next_input`` leading to a crash of terminal IPython.
    :ghpull:`10231`, :ghissue:`10296`, :ghissue:`10229`
  * Always wait for editor inputhook for terminal IPython :ghpull:`10239`,
    :ghpull:`10240`
  * Disable ``_ipython_display_`` in terminal :ghpull:`10249`, :ghpull:`10274`
  * Update terminal colors to be more visible by default on windows
    :ghpull:`10260`, :ghpull:`10238`, :ghissue:`10281`
  * Add Ctrl-Z shortcut (suspend) in terminal debugger :ghpull:`10254`,
    :ghissue:`10273`
  * Indent on new line by looking at the text before the cursor :ghpull:`10264`,
    :ghpull:`10275`, :ghissue:`9283`
  * Update QtEventloop integration to fix some matplotlib integration issues
    :ghpull:`10201`, :ghpull:`10311`, :ghissue:`10201`
  * Respect completions display style in terminal debugger :ghpull:`10305`,
    :ghpull:`10313`
  * Add a config option ``TerminalInteractiveShell.extra_open_editor_shortcuts``
    to enable extra shortcuts to open the input in an editor. These are :kbd:`v`
    in vi mode, and :kbd:`C-X C-E` in emacs mode (:ghpull:`10330`).
    The :kbd:`F2` shortcut is always enabled.
- Update to IPython 5.2.2
  * Fix error when starting with ``IPCompleter.limit_to__all__`` configured.
- Update to IPython 5.2.1
  * Fix tab completion in the debugger. :ghpull:`10223`
- Update to IPython 5.2
  * restore IPython's debugger to raise on quit. :ghpull:`10009`
  * The configuration value ``c.TerminalInteractiveShell.highlighting_style`` can
    now directly take a class argument for custom color style. :ghpull:`9848`
  * Correctly handle matplotlib figures dpi :ghpull:`9868`
  * Deprecate ``-e`` flag for the ``%%notebook`` magic that had no effects.
    :ghpull:`9872`
  * You can now press F2 while typing at a terminal prompt to edit the contents
    in your favourite terminal editor. Set the :envvar:`EDITOR` environment
    variable to pick which editor is used. :ghpull:`9929`
  * sdists will now only be ``.tar.gz`` as per upstream PyPI requirements.
    :ghpull:`9925`
  * :any:`IPython.core.debugger` have gained a ``set_trace()`` method for
    convenience. :ghpull:`9947`
  * The 'smart command mode' added to the debugger in 5.0 was removed, as more
    people preferred the previous behaviour. Therefore, debugger commands such as
    ``c`` will act as debugger commands even when ``c`` is defined as a variable.
    :ghpull:`10050`
  * Fixes OS X event loop issues at startup, :ghpull:`10150`
  * Deprecate the ``%%autoindent`` magic. :ghpull:`10176`
  * Emit a :any:`DeprecationWarning` when setting the deprecated
    ``limit_to_all`` option of the completer. :ghpull:`10198`
  * The :cellmagic:`capture` magic can now capture the result of a cell (from an
    expression on the last line), as well as printed and displayed output.
    :ghpull:`9851`.
- Update to IPython 5.1
  * Broken ``%%timeit`` on Python2 due to the use of ``__qualname__``. :ghpull:`9804`
  * Restore ``%%gui qt`` to create and return a ``QApplication`` if necessary. :ghpull:`9789`
  * Don't set terminal title by default. :ghpull:`9801`
  * Preserve indentation when inserting newlines with ``Ctrl-O``. :ghpull:`9770`
  * Restore completion in debugger. :ghpull:`9785`
  * Deprecate ``IPython.core.debugger.Tracer()`` in favor of simpler, newer, APIs. :ghpull:`9731`
  * Restore ``NoOpContext`` context manager removed by mistake, and add `DeprecationWarning`. :ghpull:`9765`
  * Add option allowing ``Prompt_toolkit`` to use 24bits colors. :ghpull:`9736`
  * Fix for closing interactive matplotlib windows on OS X. :ghpull:`9854`
  * An embedded interactive shell instance can be used more than once. :ghpull:`9843`
  * More robust check for whether IPython is in a terminal. :ghpull:`9833`
  * Better pretty-printing of dicts on PyPy. :ghpull:`9827`
  * Some coloured output now looks better on dark background command prompts in Windows.
    :ghpull:`9838`
  * Improved tab completion of paths on Windows . :ghpull:`9826`
  * Fix tkinter event loop integration on Python 2 with ``future`` installed. :ghpull:`9824`
  * Restore ``Ctrl-\`` as a shortcut to quit IPython.
  * Make ``get_ipython()`` accessible when modules are imported by startup files. :ghpull:`9818`
  * Add support for running directories containing a ``__main__.py`` file with the
    ``ipython`` command. :ghpull:`9813`
- Update to IPython 5.0
  + IPython 5 features a major upgrade to the terminal interface, bringing live
    syntax highlighting as you type, proper multiline editing and multiline paste,
    and tab completions that don't clutter up your history.
  + Backwards incompatible changes
  * The ``%%install_ext`` magic function, deprecated since 4.0, has now been deleted.
    You can distribute and install extensions as packages on PyPI.
  * Callbacks registered while an event is being handled will now only be called
    for subsequent events; previously they could be called for the current event.
    Similarly, callbacks removed while handling an event *will* always get that
    event. See :ghissue:`9447` and :ghpull:`9453`.
  * Integration with pydb has been removed since pydb development has been stopped
    since 2012, and pydb is not installable from PyPI.
  * The ``autoedit_syntax`` option has apparently been broken for many years.
    It has been removed.
  * The overhaul of the terminal interface will probably cause a range of minor
    issues for existing users.
  * IPython no longer uses readline configuration (``~/.inputrc``). We hope that
    the functionality you want (e.g. vi input mode) will be available by configuring
    IPython directly (see :doc:`/config/options/terminal`).
  * The ``PromptManager`` class has been removed, and the prompt machinery simplified.
  * There are new options to configure the colours used in syntax highlighting.
    We have tried to integrate them with our classic  ``--colors`` option and
    ``%%colors`` magic, but there's a mismatch in possibilities, so some configurations
    may produce unexpected results. See :ref:`termcolour` for more information.
  * The new interface is not compatible with Emacs 'inferior-shell' feature. To
    continue using this, add the ``--simple-prompt`` flag to the command Emacs
    runs. This flag disables most IPython features, relying on Emacs to provide
    things like tab completion.
  + Provisional Changes
  * When running via the Jupyter notebook interfaces, or other compatible client,
    you can enable rich documentation experimental functionality:
    When the ``docrepr`` package is installed setting the boolean flag
    ``InteractiveShell.sphinxify_docstring`` to ``True``, will process the various
    object through sphinx before displaying them (see the ``docrepr`` package
    documentation for more information.
  + Deprecated Features
  * ``hooks.fix_error_editor`` seems unused and is pending deprecation.
  * `IPython/core/excolors.py:ExceptionColors` is  deprecated.
  * `IPython.core.InteractiveShell:write()` is deprecated; use `sys.stdout` instead.
  * `IPython.core.InteractiveShell:write_err()` is deprecated; use `sys.stderr` instead.
  * The `formatter` keyword argument to `Inspector.info` in `IPython.core.oinspec` has no effect.
  * The `global_ns` keyword argument of IPython Embed was deprecated, and has no effect. Use `module` keyword argument instead.
- Update to IPython 4.2
  * Fix ``ipython -i`` on errors, which was broken in 4.1.
  * The delay meant to highlight deprecated commands that have moved to jupyter has been removed.
  * Improve compatibility with future versions of traitlets and matplotlib.
  * Use stdlib :func:`python:shutil.get_terminal_size` to measure terminal width when displaying tracebacks
    (provided by ``backports.shutil_get_terminal_size`` on Python 2).
- Update to IPython 4.1.2
  * fixes installation issues with some versions of setuptools.
* Thu Mar 16 2017 jmatejek@suse.com
- do not Recommend jupyter_nbconvert (which pulls in texlive)
* Wed Feb 17 2016 toddrme2178@gmail.com
- specfile:
  * update copyright year
  * Simplify tests for determining whether to build pdf documentation
- update to version 4.1.1:
  * Backport #9209: Don't import IPython to check version number in
    setup
- Update to 4.1.0
  * Release February, 2016. IPython 4.1 contain mostly bug fixes.
    It though contain a few improvement.
  * IPython debugger (IPdb) now supports the number of context
    lines for the where (and w) commands. The context keyword is
    also available in various APIs. See PR :ghpull:`9097`
  * YouTube video will now show thumbnail when exported to a media
    that do not support video. (:ghpull:`9086`)
  * Add warning when running ipython <subcommand> when subcommand
    is deprecated. jupyter should now be used.
  * Code in %%pinfo (also known as ??) are now highlighter
    (:ghpull:`8947`)
  * %%aimport now support module completion. (:ghpull:`8884`)
  * ipdb output is now colored ! (:ghpull:`8842`)
  * Add ability to transpose columns for completion:
    (:ghpull:`8748`)
  * Many many docs improvements and bug fixes
- update to version 4.0.3:
  * Python 3.5 bug in that could crash during shutdown, triggered by
    deprecations in traitlets 4.1.
  * Typo in deprecation message for nbconvert
- update to version 4.0.2:
  * Fix backward-compatiblity shim for "IPython.Config", which
    should have been deprecated instead of removed. This will be
    removed in 5.0.
- update to version 4.0.1:
  * Installation on some systems
  * Compatibility with CPython 3.4.4
  * Compatibility with Qt5
* Thu Oct  1 2015 toddrme2178@gmail.com
- Build documentation
  This is in a separate spec file to avoid dependency loops
- Obsolete IPython
- Split the iptest executable into its own subpackage
  This has a bunch of testing dependencies that are not otherwise
  necessary.
* Fri Aug 21 2015 toddrme2178@gmail.com
- Add conflict with older versions of IPython
* Mon Aug 17 2015 toddrme2178@gmail.com
- Initial version
